@@ -1013,6 +1013,9 @@ Sentence sentence_create(const char *input_string, Dictionary dict)
 	sent->q_pruned_rules = FALSE;
 	sent->is_conjunction = NULL;
 
+	sent->dptr = NULL;
+	sent->deletable = NULL;
+
 	/* Make a copy of the input */
 	sent->orig_sentence = string_set_add (input_string, sent->string_set);
 
@@ -1141,6 +1144,12 @@ int sentence_parse(Sentence sent, Parse_Options opts)
 
 	verbosity = opts->verbosity;
 
+	/* Cleanup stuff previously allocated. This is because some free 
+	 * routines depend on sent-length, which might change in different
+	 * parse-opts settings. 
+	 */
+	free_deletable(sent);
+
 	rc = split_sentence(sent, opts);
 	if (rc) return -1;
 
