@@ -14,6 +14,7 @@
 #endif
 
 #include "api.h"
+#include "corpus/corpus.h"
 #include "error.h"
 #include "jni-client.h"
 #include "utilities.h"
@@ -180,7 +181,7 @@ static void r_printTree(CNode* cn, int level)
 	int i;
 	CNode* c;
 
-	if (cn==NULL) return;
+	if (cn == NULL) return;
 
 	/* print label */
 	if (cn->label != NULL) {
@@ -423,6 +424,7 @@ Java_org_linkgrammar_LinkGrammar_getWord(JNIEnv *env, jclass cls, jint i)
 
 	/* FWIW, j will be null if w is utf8-encoded Japanese or Chinese.
 	 * I guess my JVM is not capable of handling Chinese/Japanese ??
+	 * Maybe some special java thing needs to be installed?
 	 */
 	jstring j = (*env)->NewStringUTF(env, w);
 	return j;
@@ -443,15 +445,66 @@ Java_org_linkgrammar_LinkGrammar_getLinkageWord(JNIEnv *env, jclass cls, jint i)
 JNIEXPORT jstring JNICALL
 Java_org_linkgrammar_LinkGrammar_getLinkageDisjunct(JNIEnv *env, jclass cls, jint i)
 {
+	jstring j;
 	per_thread_data *ptd = get_ptd(env, cls);
 
 	/* does not need to be freed, points into data structures */
 	/* returns the inflected word. */
 	const char * w = linkage_get_disjunct(ptd->linkage, i);
-	jstring j = (*env)->NewStringUTF(env, w);
+	if (NULL == w) j = NULL;
+	else j = (*env)->NewStringUTF(env, w);
 	return j;
 }
 
+JNIEXPORT jstring JNICALL
+Java_org_linkgrammar_LinkGrammar_getLinkageSense(JNIEnv *env, 
+                    jclass cls, jint i, jint j)
+{
+	per_thread_data *ptd = get_ptd(env, cls);
+	Linkage lkg = ptd->linkage;
+	Linkage_info *lifo = lkg->info;
+	Sense *sns;
+	const char * w = NULL;
+	jstring js;
+
+	lg_corpus_linkage_senses(lkg);
+	sns = lg_get_word_sense(lifo, i);
+	while ((0 < j) && sns)
+	{
+		sns = lg_sense_next(sns);
+		j--;
+	}
+	
+	/* does not need to be freed, points into data structures */
+	if (sns) w = lg_sense_get_sense(sns);
+
+	if (w) js = (*env)->NewStringUTF(env, w);
+	else js = NULL;
+	return js;
+}
+
+JNIEXPORT jdouble JNICALL
+Java_org_linkgrammar_LinkGrammar_getLinkageSenseScore(JNIEnv *env, 
+                    jclass cls, jint i, jint j)
+{
+	per_thread_data *ptd = get_ptd(env, cls);
+	Linkage lkg = ptd->linkage;
+	Linkage_info *lifo = lkg->info;
+	Sense *sns;
+	double score = 0.0;
+
+	sns = lg_get_word_sense(lifo, i);
+	while ((0 < j) && sns)
+	{
+		sns = lg_sense_next(sns);
+		j--;
+	}
+	
+	if (sns) score = lg_sense_get_score(sns);
+
+	return score;
+}
+
 /*
  * Class:		 LinkGrammar
  * Method:		numSkippedWords
