@@ -335,7 +335,11 @@ struct Linkage_info_struct
     double corpus_cost;
     Andlist * andlist;
     int island[MAX_SENTENCE];
-    char *disjunct_list_str[MAX_SENTENCE];
+    size_t nwords;
+    char **disjunct_list_str;
+#ifdef USE_CORPUS
+    Sense **sense_list;
+#endif
 };
 
 struct List_o_links_struct
