@@ -30,6 +30,21 @@
 /*static char * strip_left[] = {"(", "$", "``", NULL}; */
 /*static char * strip_right[] = {")", "%", ",", ".", ":", ";", "?", "!", "''", "'", "'s", NULL};*/
 
+#define COMMON_ENTITY_MARKER   "<marker-common-entity>"
+
+/**
+ * is_common_entity - Return true if word is a common noun or adjective
+ * Common nouns and adjectives are typically used in corporate entity
+ * names -- e.g. "Sun State Bank" -- "sun", "state" and "bank" are all 
+ * common nouns.
+ */
+static int is_common_entity(Dictionary dict, const char * str)
+{
+	if (word_contains(dict, str, COMMON_ENTITY_MARKER) == 1)
+		return 1;
+	return 0;
+}
+
 /**
  * Is the word entirely composed of single-letter abreviations
  * (followed by a period)?
@@ -63,6 +78,40 @@ static int is_proper_name(const char * word)
 	return is_utf8_upper(word);
 }
 
+/* Create a string containing anything that can be construed to
+ * be a quotation mark. This works, because link-grammar is more
+ * or less ignorant of quotes at this time.
+ */
+static const wchar_t *list_of_quotes(void) 
+{
+#define QUSZ 50
+	static wchar_t wqs[QUSZ];
+	mbstate_t mbs;
+	/* Single-quotes are used for abbreviations, don't mess with them */
+	/* const char * qs = "\"\'«»《》【】『』‘’`„“"; */
+	const char * qs = "\"«»《》【】『』`„“";
+
+	const char *pqs = qs;
+
+	memset(&mbs, 0, sizeof(mbs));
+
+	mbsrtowcs(wqs, &pqs, QUSZ, &mbs);
+
+	return wqs;
+}
+
+/**
+ * Return TRUE if the character is a quotation character.
+ */
+static int is_quote(wchar_t wc)
+{
+	static const wchar_t *quotes = NULL;
+	if (NULL == quotes) quotes = list_of_quotes();
+
+	if (NULL !=  wcschr(quotes, wc)) return TRUE;
+	return FALSE;
+}
+
 /**
  * Returns true if the word can be interpreted as a number.
  * The ":" is included here so we allow "10:30" to be a number.
@@ -577,7 +626,7 @@ static int separate_word(Sentence sent, Parse_Options opts,
 		return FALSE;
 	}
 
-	if (quote_found == TRUE) sent->post_quote[sent->length]=1;
+	if (quote_found == TRUE) sent->post_quote[sent->length] = 1;
 
 	/* If the word is still not being found, then it might be 
 	 * a run-on of two words. Ask the spell-checker to split
@@ -663,19 +712,28 @@ int separate_sentence(Sentence sent, Parse_Options opts)
 	is_first = TRUE;
 	for(;;) 
 	{
+		int isq;
 		wchar_t c;
 		int nb = mbrtowc(&c, s, MB_CUR_MAX, &mbs);
 		quote_found = FALSE;
 
 		if (0 > nb) goto failure;
 
-		/* skip all whitespace */
-		while (iswspace(c) || (c == '\"'))
+		/* Skip all whitespace. Also, ignore *all* quotation marks.
+		 * XXX This is sort-of a hack, but that is because LG does
+		 * not have any intelligent support for quoted character
+		 * strings at this time.
+		 */
+		isq = is_quote (c);
+		if (isq) quote_found = TRUE;
+		while (iswspace(c) || isq)
 		{
 			s += nb;
-			if (*s == '\"') quote_found = TRUE;
 			nb = mbrtowc(&c, s, MB_CUR_MAX, &mbs);
+			if (0 == nb) break;
 			if (0 > nb) goto failure;
+			isq = is_quote (c);
+			if (isq) quote_found = TRUE;
 		}
 
 		if (*s == '\0') break;
@@ -683,7 +741,7 @@ int separate_sentence(Sentence sent, Parse_Options opts)
 		t = s;
 		nb = mbrtowc(&c, t, MB_CUR_MAX, &mbs);
 		if (0 > nb) goto failure;
-		while (!iswspace(c) && (c != '\"') && (c != 0) && (nb != 0))
+		while (!iswspace(c) && !is_quote(c) && (c != 0) && (nb != 0))
 		{
 			t += nb;
 			nb = mbrtowc(&c, t, MB_CUR_MAX, &mbs);
@@ -940,14 +998,14 @@ static void guess_misspelled_word(Sentence sent, int i, char * s)
  * Now, we correct the first word, w.
  * If w is upper case, let w' be the lower case version of w.
  * If both w and w' are in the dict, concatenate these disjncts.
- * Else if w' is in dict, use disjuncts of w',
- * else leave the disjuncts alone.
+ * Else if just w' is in dict, use disjuncts of w', together with
+ * the CAPITALIZED-WORDS rule.
+ * Else leave the disjuncts alone.
  */
 int build_sentence_expressions(Sentence sent, Parse_Options opts)
 {
 	int i, first_word;  /* the index of the first word after the wall */
 	char *s, temp_word[MAX_WORD+1];
-	const char * u;
 	const char * regex_name;
 	X_node * e;
 	Dictionary dict = sent->dict;
@@ -1042,6 +1100,8 @@ int build_sentence_expressions(Sentence sent, Parse_Options opts)
 	 * or if it follows a colon or a quotation mark--a word that's 
 	 * capitalized has to be looked up as an uncapitalized word
 	 * (as well as a capitalized word).
+	 * XXX This rule is English-language-oriented, and should be
+	 * abstracted.
 	 */
 	for (i=0; i<sent->length; i++)
 	{
@@ -1050,30 +1110,40 @@ int build_sentence_expressions(Sentence sent, Parse_Options opts)
 		       sent->post_quote[i] == 1)) continue;
 		s = sent->word[i].string;
 
+		/* If the lower-case version of this word is in the dictionary, 
+		 * then add the disjuncts for the lower-case version. The upper
+		 * case version disjuncts had previously come from matching the 
+		 * CAPITALIZED-WORDS regex.
+		 *
+		 * Err .. add the lower-case version only if the lower-case word
+		 * is a common noun or adjective; otherwise, *replace* the
+		 * upper-case word with the lower-case one.  This allows common
+		 * nouns and adjectives to be used for entity names: e.g.
+		 * "Great Southern Union declares bankruptcy", allowing Great
+		 * to be capitalized, while preventing an upper-case "She" being
+		 * used as a proper name in "She declared bankruptcy".
+		 *
+		 * This is actually a great example of a combo of an algorithm
+		 * together with a list of words used to determine grammatical
+		 * function.
+		 */
 		if (is_utf8_upper(s))
 		{
+			const char * lc;
 			downcase_utf8_str(temp_word, s, MAX_WORD);
-			u = string_set_add(temp_word, sent->string_set);
+			lc = string_set_add(temp_word, sent->string_set);
 
-			/* If the lower-case version is in the dictionary... */
-			if (boolean_dictionary_lookup(sent->dict, u))
+			if (boolean_dictionary_lookup(sent->dict, lc))
 			{
-				/* Then check if the upper-case version is there. 
-				 * If it is, the disjuncts for the upper-case version 
-				 * have been put there already. So add on the disjuncts
-				 * for the lower-case version. */
-				if (boolean_dictionary_lookup(sent->dict, s))
+				if (is_common_entity(sent->dict,lc))
 				{
-					e = build_word_expressions(sent, u);
+					e = build_word_expressions(sent, lc);
 					sent->word[i].x =
 						catenate_X_nodes(sent->word[i].x, e);
-				} 
+				}
 				else
 				{
-					/* If the upper-case version isn't there,
-					 * replace the u.c. disjuncts with l.c. ones.
-					 */
-					safe_strcpy(s,u, MAX_WORD);
+					safe_strcpy(s, lc, MAX_WORD);
 					e = build_word_expressions(sent, s);
 					free_X_nodes(sent->word[i].x);
 					sent->word[i].x = e;
